==> haskell-either-4.4.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-either/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-9b4e1ab30e64d0a7367f7fb822cda30c
key: eithe_74HhqcO0UmFHapRk6vd5kg
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-74HhqcO0UmFHapRk6vd5kg
depends:
    MonadRandom-0.4.2.3-c1a87dea4099c830800b3ad78538235a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.3-bc094c1e88d075fab4936b454b930127
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    free-4.12.4-8e24958a2bab136eded09b725d82baf6
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    profunctors-5.2-5f15e32dcb12ed9b3b3c97537d07181e
    semigroupoids-5.0.1-8eb2d2c8f0f0def85cbb7c35538a003a
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-4.4.1-14-armv7h.pkg.tar.xz: usr/share/haskell/haskell-either/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1
id: either-4.4.1-6e9670c0aa10adc0c05cea76c41fcbb1
key: eithe_0Q1zua8x1k4AxBVAOxuEUE
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/either-4.4.1
hs-libraries: HSeither-4.4.1-0Q1zua8x1k4AxBVAOxuEUE
depends:
    MonadRandom-0.4.2.2-41c453a4d3603a1aafaf1f31fe6ac694
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
